@@ -2,8 +2,8 @@
 Includes class LennardJones and several methods to relax and compute forces and energies from Lennard-Jones clusters
 
 """
-import pyximport
-pyximport.install()
+# import pyximport
+# pyximport.install()
 
 from .lj import LennardJones, lj_compact_evaluate
 from .lj_utils import lj_energy, lj_forces, lj_gradient
